@@ -7,8 +7,10 @@ class SDK:
         # Si se le indica el procesador
         self._sdk = None
         if processor == 'mercadopago':
+            self.processor = 'mercagopado'
             self._sdk = MercadoPagoSDK(merchant, marketplace=marketplace)
         elif processor == 'decidir':
+            self.processor = 'decidir'
             self._sdk = DecidirSDK(merchant, merchant_cadena)
 
     def customer(self):
