@@ -1,7 +1,7 @@
 import requests
 import json
 
-from ..response import ok
+from ..response import ok, error
 
 
 class CardToken:
@@ -27,4 +27,6 @@ class CardToken:
         r = requests.post(self.url + '/tokens', headers=self.headers, data=json.dumps(body))
         self.headers['apikey'] = self.private_key
         response = r.json()
+        if r.status_code > 299:
+            return error(response)
         return ok(response)
