@@ -4,7 +4,7 @@ import random
 import string
 from iso8601 import parse_date
 from ..response import ok, error
-
+from datetime import datetime
 
 def _format_card(response):
     if 'card' in response:
@@ -57,7 +57,8 @@ def _format(response):
         'status': response['status'],
         'status_detail': response['status_detail'],
         'card': _format_card(response),
-        'processor': 'decidir'
+        'processor': 'decidir',
+        'payment_day':datetime.now()
     }
     return result
 
