@@ -12,7 +12,7 @@ class CardToken:
             card['id'] = card['mercadopago_id']
 
         data = {
-            "id": card['id']
+            "card_id": card['id']
         }
         card_token_response = self.sdk.card_token().create(data)
 
