@@ -7,20 +7,16 @@ from .Refund import Refund
 
 
 class MercadoPagoSDK:
-    def __init__(self, merchant, marketplace=False):
+    def __init__(self, merchant: dict, marketplace: bool = False):
         active = True
-        if 'credentials' in merchant:
-            if not marketplace:
-                access_token = merchant['credentials']['mercadopago']['access_token']
-                active = merchant['credentials']['mercadopago']['active']
-            else:
-                access_token = merchant['credentials']['mp_marketplace']['access_token']
-                active = merchant['credentials']['mp_marketplace']['active']
+        if 'credentials' in merchant and 'mercadopago' in merchant['credentials'] and not marketplace:
+            access_token = merchant['credentials']['mercadopago']['access_token']
+            active = merchant['credentials']['mercadopago']['active']
+        elif 'credentials' in merchant and 'mp_marketplace' in merchant['credentials'] and marketplace:
+            access_token = merchant['credentials']['mp_marketplace']['access_token']
+            active = merchant['credentials']['mp_marketplace']['active']
         else:
-            if not marketplace:
-                access_token = merchant['keys']['access_token']
-            else:
-                access_token = merchant['keys_marketplace']['access_token']
+            access_token = merchant['keys_marketplace']['access_token'] if marketplace else merchant['keys']['access_token']
         self.sdk = mercadopago.SDK(access_token) if active else None
         self.merchant_id = merchant['_id']
         self.merchant_name = merchant['name']
