@@ -1,6 +1,6 @@
 import mercadopago
 from iso8601 import parse_date
-
+from datetime import datetime
 from ..response import ok, error
 
 
@@ -25,7 +25,8 @@ def _format(response):
         'status': response['status'],
         'status_detail': response['status_detail'],
         'card': _format_card(response),
-        'processor': 'mercadopago'
+        'processor': 'mercadopago',
+        'payment_day':datetime.now()
     }
 
 
